I, Laurent Berge, hereby grant irrevocable permission to redistribute
and re-license the relevant code from the fixest project under the MIT
License. The relevant code is the following:

- The script to generate benchmark data (https://github.com/lrberge/fixest/blob/master/_BENCHMARK/Data%20generation.R)
- The c++ function cpp_cholesky (https://github.com/lrberge/fixest/blob/dbe56c5d953deb797a61dfc37f6e25fd143c68d4/src/lm_related.cpp#L105).
